==> ejc-jlincome-impl-3.0.0-20240516.025626-79-sources.jar: com/ejianc/business/jlincome/performance/controller/GradeAdjustController.java <==
package com.ejianc.business.jlincome.performance.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.ejianc.foundation.orgcenter.api.IEmployeeApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.jlincome.performance.bean.GradeAdjustEntity;
import com.ejianc.business.jlincome.performance.service.IGradeAdjustService;
import com.ejianc.business.jlincome.performance.vo.GradeAdjustVO;

/**
 * 绩效管理-成绩调整-主表
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("gradeAdjust")
public class GradeAdjustController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "GRADE_ADJUST_CODE";//此处需要根据实际修改

    @Autowired
    private IGradeAdjustService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<GradeAdjustVO> saveOrUpdate(@RequestBody GradeAdjustVO saveOrUpdateVO) {
    	GradeAdjustEntity entity = BeanMapper.map(saveOrUpdateVO, GradeAdjustEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                //entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	GradeAdjustVO vo = BeanMapper.map(entity, GradeAdjustVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<GradeAdjustVO> queryDetail(Long id) {
    	GradeAdjustEntity entity = service.selectById(id);
    	GradeAdjustVO vo = BeanMapper.map(entity, GradeAdjustVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<GradeAdjustVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (GradeAdjustVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(GradeAdjustVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<GradeAdjustVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("bill_code");
        fuzzyFields.add("contract_name");
        fuzzyFields.add("customer_name");
        fuzzyFields.add("org_name");
        fuzzyFields.add("employee_name");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }

        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, departmentIds));
        }

        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        /**
         * 根据月份查询
         */
        if(ObjectUtils.isNotEmpty(param.getParams().get("initiationMonth"))) {
            param.getParams().put("initiationMonth", new Parameter(QueryParam.IN, param.getParams().get("initiationMonth").getValue() + "-01"));
        }
        IPage<GradeAdjustEntity> page = service.queryPage(param,false);
        IPage<GradeAdjustVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), GradeAdjustVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("bill_code");
        fuzzyFields.add("contract_name");
        fuzzyFields.add("customer_name");
        fuzzyFields.add("org_name");
        fuzzyFields.add("employee_name");

        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        //param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        UserContext userContextCache =sessionManager.getUserContext();
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }

        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, departmentIds));
        }

        /**
         * 根据月份查询
         */
        if(ObjectUtils.isNotEmpty(param.getParams().get("initiationMonth"))) {
            param.getParams().put("initiationMonth", new Parameter(QueryParam.IN, param.getParams().get("initiationMonth").getValue() + "-01"));
        }

        List<GradeAdjustEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        beans.put("contractMnySum",list.stream().map(GradeAdjustEntity::getContractMny).reduce(BigDecimal.ZERO,BigDecimal::add));
        ExcelExport.getInstance().export("GradeAdjust-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refGradeAdjustData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<GradeAdjustVO>> refGradeAdjustData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<GradeAdjustEntity> page = service.queryPage(param,false);
        IPage<GradeAdjustVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), GradeAdjustVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> ejc-jlincome-impl-3.0.0-20240531.093608-137-sources.jar: com/ejianc/business/jlincome/performance/controller/GradeAdjustController.java <==
package com.ejianc.business.jlincome.performance.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.ejianc.business.jlincome.performance.bean.GradeAdjustDetailEntity;
import com.ejianc.business.jlincome.performance.service.IGradeAdjustDetailService;
import com.ejianc.business.jlincome.performance.vo.GradeAdjustDetailVO;
import com.ejianc.foundation.orgcenter.api.IEmployeeApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.jlincome.performance.bean.GradeAdjustEntity;
import com.ejianc.business.jlincome.performance.service.IGradeAdjustService;
import com.ejianc.business.jlincome.performance.vo.GradeAdjustVO;

/**
 * 绩效管理-成绩调整-主表
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("gradeAdjust")
public class GradeAdjustController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "GRADE_ADJUST_CODE";//此处需要根据实际修改

    @Autowired
    private IGradeAdjustService service;
    @Autowired
    private IGradeAdjustDetailService detailService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<GradeAdjustVO> saveOrUpdate(@RequestBody GradeAdjustVO saveOrUpdateVO) {
    	GradeAdjustEntity entity = BeanMapper.map(saveOrUpdateVO, GradeAdjustEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                //entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	GradeAdjustVO vo = BeanMapper.map(entity, GradeAdjustVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<GradeAdjustVO> queryDetail(Long id) {
    	GradeAdjustEntity entity = service.selectById(id);
    	GradeAdjustVO vo = BeanMapper.map(entity, GradeAdjustVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<GradeAdjustVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (GradeAdjustVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(GradeAdjustVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<GradeAdjustVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("bill_code");
        fuzzyFields.add("contract_name");
        fuzzyFields.add("customer_name");
        fuzzyFields.add("org_name");
        fuzzyFields.add("employee_name");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        //UserContext userContextCache =sessionManager.getUserContext();
        ////当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        //String authOrgIds = userContextCache.getAuthOrgIds();
        //List<OrgVO> orgVOList = null;
        //if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
        //    orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        //}else {//pc端查询
        //    orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        //}
        ////普通组织 id
        //List<Long> commonOrgIds = new ArrayList<>();
        ////项目部 id
        //List<Long> departmentIds = new ArrayList<>();
        //orgVOList.stream().forEach(org -> {
        //    if(5 == org.getOrgType()) {
        //        //项目部
        //        departmentIds.add(org.getId());
        //    } else {
        //        //普通组织
        //        commonOrgIds.add(org.getId());
        //    }
        //
        //});
        //if(CollectionUtils.isNotEmpty(commonOrgIds)) {
        //    /** 要求主表有orgId字段，保存单据所属组织 */
        //    param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        //} else if(CollectionUtils.isNotEmpty(departmentIds)) {
        //    /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
        //    param.getParams().put("orgId", new Parameter(QueryParam.IN, departmentIds));
        //}
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        /**
         * 根据月份查询
         */
        if(ObjectUtils.isNotEmpty(param.getParams().get("initiationMonth"))) {
            param.getParams().put("initiationMonth", new Parameter(QueryParam.IN, param.getParams().get("initiationMonth").getValue() + "-01"));
        }
        IPage<GradeAdjustEntity> page = service.queryPage(param,false);
        IPage<GradeAdjustVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), GradeAdjustVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("bill_code");
        fuzzyFields.add("contract_name");
        fuzzyFields.add("customer_name");
        fuzzyFields.add("org_name");
        fuzzyFields.add("employee_name");

        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        //param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        //UserContext userContextCache =sessionManager.getUserContext();
        //String authOrgIds = userContextCache.getAuthOrgIds();
        //List<OrgVO> orgVOList = null;
        //if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
        //    orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        //}else {//pc端查询
        //    orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        //}
        ////普通组织 id
        //List<Long> commonOrgIds = new ArrayList<>();
        ////项目部 id
        //List<Long> departmentIds = new ArrayList<>();
        //orgVOList.stream().forEach(org -> {
        //    if(5 == org.getOrgType()) {
        //        //项目部
        //        departmentIds.add(org.getId());
        //    } else {
        //        //普通组织
        //        commonOrgIds.add(org.getId());
        //    }
        //
        //});
        //if(CollectionUtils.isNotEmpty(commonOrgIds)) {
        //    /** 要求主表有orgId字段，保存单据所属组织 */
        //    param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        //} else if(CollectionUtils.isNotEmpty(departmentIds)) {
        //    /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
        //    param.getParams().put("orgId", new Parameter(QueryParam.IN, departmentIds));
        //}

        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

        /**
         * 根据月份查询
         */
        if(ObjectUtils.isNotEmpty(param.getParams().get("initiationMonth"))) {
            param.getParams().put("initiationMonth", new Parameter(QueryParam.IN, param.getParams().get("initiationMonth").getValue() + "-01"));
        }

        List<GradeAdjustEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        beans.put("contractMnySum",list.stream().map(GradeAdjustEntity::getContractMny).reduce(BigDecimal.ZERO,BigDecimal::add));
        ExcelExport.getInstance().export("GradeAdjust-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refGradeAdjustData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<GradeAdjustVO>> refGradeAdjustData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<GradeAdjustEntity> page = service.queryPage(param,false);
        IPage<GradeAdjustVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), GradeAdjustVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    /**
     * 根据合同Id查询子表数据
     * @param contractId
     * @return
     */
     @RequestMapping(value = "/selectByContract", method = RequestMethod.GET)
     @ResponseBody
     public CommonResponse<List<GradeAdjustDetailVO>> selectByContract(Long contractId){
        logger.info("合同selectByContract"+contractId);
        //
         LambdaQueryWrapper<GradeAdjustEntity> lambda = new LambdaQueryWrapper<>();
         lambda.in(GradeAdjustEntity::getBillState, BillStateEnum.COMMITED_STATE.getBillStateCode(),BillStateEnum.PASSED_STATE.getBillStateCode());
         lambda.eq(GradeAdjustEntity::getContractId,contractId);
         lambda.orderByDesc(GradeAdjustEntity::getCreateTime);
         List<GradeAdjustEntity> list = service.list(lambda);
         if (ObjectUtils.isNotEmpty(list)){
             LambdaQueryWrapper<GradeAdjustDetailEntity> lambda2 = new LambdaQueryWrapper<>();
             lambda2.eq(GradeAdjustDetailEntity::getDetailId,list.get(0).getId());
             List<GradeAdjustDetailEntity> result = detailService.list(lambda2);
             List<GradeAdjustDetailVO> gradeAdjustDetailVOS = BeanMapper.mapList(result, GradeAdjustDetailVO.class);
             return CommonResponse.success("查询成功",gradeAdjustDetailVOS);
         }
        return CommonResponse.success("不存在价格调整");
     }
}
